@@ -1,7 +1,7 @@
 package Data::Dmp;
 
-our $DATE = '2016-04-30'; # DATE
-our $VERSION = '0.19'; # VERSION
+our $DATE = '2016-06-03'; # DATE
+our $VERSION = '0.20'; # VERSION
 
 use 5.010001;
 use strict;
@@ -178,7 +178,7 @@ sub _dd_or_dmp {
 
     if ($_is_dd) {
         say $res;
-        return @_;
+        return wantarray() || @_ > 1 ? @_ : $_[0];
     } else {
         return $res;
     }
@@ -202,7 +202,7 @@ Data::Dmp - Dump Perl data structures as Perl code
 
 =head1 VERSION
 
-This document describes version 0.19 of Data::Dmp (from Perl distribution Data-Dmp), released on 2016-04-30.
+This document describes version 0.20 of Data::Dmp (from Perl distribution Data-Dmp), released on 2016-06-03.
 
 =head1 SYNOPSIS
 
@@ -264,21 +264,21 @@ Note that without the pragmas, the dump might be incorrect.
 
  [1..10]:
                       Rate    Data::Dump Data::Dumper Data::Dmp
- Data::Dump    28111+-32/s            --       -67.7%    -74.9%
- Data::Dumper 86920+-100/s  209.19+-0.5%           --    -22.4%
- Data::Dmp     112028+-0/s 298.53+-0.45% 28.89+-0.15%        --
+ Data::Dump    21199+-23/s            --       -67.3%    -76.4%
+ Data::Dumper 64920+-110/s 206.24+-0.62%           --    -27.7%
+ Data::Dmp     89744+-27/s 323.34+-0.47% 38.24+-0.24%        --
  
  [1..100]:
-                       Rate  Data::Dump   Data::Dmp Data::Dumper
- Data::Dump   3353.9+-6.9/s          --      -76.2%       -77.5%
- Data::Dmp      14119+-21/s   321+-1.1%          --        -5.2%
- Data::Dumper   14897+-71/s 344.2+-2.3% 5.51+-0.53%           --
+                        Rate    Data::Dump   Data::Dmp Data::Dumper
+ Data::Dump    2667.7+-2.7/s            --      -76.0%       -76.2%
+ Data::Dmp    11131.4+-3.1/s 317.27+-0.43%          --        -0.6%
+ Data::Dumper    11199+-57/s   319.8+-2.2% 0.61+-0.51%           --
  
  Some mixed structure:
-                     Rate   Data::Dump    Data::Dmp Data::Dumper
- Data::Dump    8200+-17/s           --       -69.6%       -80.9%
- Data::Dmp    26968+-47/s 228.9+-0.91%           --       -37.2%
- Data::Dumper 42964+-47/s    424+-1.3% 59.32+-0.33%           --
+                     Rate Data::Dump    Data::Dmp Data::Dumper
+ Data::Dump    6096+-16/s         --       -68.4%       -80.5%
+ Data::Dmp    19284+-39/s  216.3+-1%           --       -38.5%
+ Data::Dumper 31335+-94/s    414+-2% 62.49+-0.58%           --
 
 =head1 FUNCTIONS
 
